@@ -2,20 +2,23 @@
 from airzone.protocol import Gateway
 
 
-def airzone_factory(serial, port, machineId, system='innobus'):
+def airzone_factory(serial, port, machineId, system="innobus", **kwargs):
     gat = Gateway(serial, port)
     if system == 'innobus':
         from airzone.innobus import Machine
         m = Machine(gat, machineId)
     else:
         from airzone.aido import Aido
-        m = Aido(gat, machineId)
+        m = Aido(gat, machineId, **kwargs)
     return m
 
 
 
 if __name__ == '__main__':
-    m = airzone_factory('modbus.local', 5020, 1)    
+    aido_args = {"has_louvres": False, "speed_as_per": True}    
+    m = airzone_factory('modbus.local', 5020, 1, "aido", **aido_args)
+    #m = airzone_factory('modbus.local', 5020, 1, "aido")
+    
     z = m.get_zones()[0]
     print(m._machine_state)
     print (z._zone_state)
